#!/bin/sh
#
# besrelay.sh: Starts the BigFix Relay
#
# description: Starts the BigFix Relay service
# processname: BESRelay

setup_configfile() {
	if [ -f /usr/bin/perl ]; then
		masthead=$1
		configfile=$2
		gatherurl=$3

		echo >> $configfile

		echo "[Software\\BigFix\\Enterprise Server]" >> $configfile
		echo -e "__Installer_Masthead_GatherURL\t\t= $gatherurl\n" >> $configfile

		URL=$( /usr/bin/perl -ne 'if( m#^X-Fixlet-Site-Registration-URL:\s+([[:print:]]+)# ) { print $1; }' $masthead )
		if [ -n "$URL" ]; then
			echo "[Software\\BigFix\\EnterpriseClient\\Settings\\Client\\_Enterprise Server_ClientRegister_ParentRelayURL]" >> $configfile
			echo -e "value\t\t= $URL\n" >> $configfile
		fi

		URL=$( /usr/bin/perl -ne 'if( m#^X-Fixlet-Site-Report-URL:\s+([[:print:]]+)# ) { print $1; }' $masthead )
		PORT=$( /usr/bin/perl -ne 'if( m#^X-Fixlet-Site-Report-URL:\s+http://\S+:(\d+)# ) { print $1; }' $masthead )
		if [ -n "$URL" ]; then
			echo "[Software\\BigFix\\EnterpriseClient\\Settings\\Client\\_BESRelay_PostResults_ParentRelayURL]" >> $configfile
			echo -e "value\t\t= $URL\n" >> $configfile
			echo "[Software\\BigFix\\EnterpriseClient\\Settings\\Client\\_BESRelay_HTTPServer_PortNumber]" >> $configfile
			echo -e "value\t\t= $PORT\n" >> $configfile
		fi

		URL=$(  /usr/bin/perl -ne 'if( m#^X-Fixlet-Site-Gather-URL:\s+(http://\S+:\d+)# ) { print $1; }' $masthead )
		PORT=$( /usr/bin/perl -ne 'if( m#^X-Fixlet-Site-Gather-URL:\s+http://\S+:(\d+)# ) { print $1; }' $masthead )
		if [ -n "$URL" -a -n "$PORT" ]; then
			echo "[Software\\BigFix\\Enterprise Server\\GatherService]" >> $configfile
			echo -e "HttpContentLocation\t\t= $URL/bfmirror/bfsites\n" >> $configfile

			echo "[Software\\BigFix\\EnterpriseClient\\Settings\\Client\\_Enterprise Server_ClientRegister_UDPMessagePort]" >> $configfile
			echo -e "value\t\t= $PORT\n" >> $configfile
		fi

		URL=$( /usr/bin/perl -ne 'if( m#^X-BES-Mirror-Gather-URL:\s+([[:print:]]+)# ) { print $1; }' $masthead )
		if [ -n "$URL" ]; then
			echo "[Software\\BigFix\\EnterpriseClient\\Settings\\Client\\_BESGather_Comm_ParentRelayURL]" >> $configfile
			echo -e "value\t\t= $URL\n" >> $configfile
		fi

		URL=$( /usr/bin/perl -ne 'if( m#^X-BES-Mirror-Download-URL:\s+([[:print:]]+)# ) { print $1; }' $masthead )
		if [ -n "$URL" ]; then
			echo "[Software\\BigFix\\Enterprise Server\\GatherService]" >> $configfile
			echo -e "DownloadMirror URL\t\t= $URL\n" >> $configfile
		fi
	fi
}

start() {
	SKIP_CLIENT_RESTART="${SKIP_CLIENT_RESTART:-noskip$1}"

	echo SKIP_CLIENT_RESTART: "$SKIP_CLIENT_RESTART"

	GATHERURL_CONFIG=""
	relayConfigPath=/var/opt/BESRelay/besrelay.config
	
	if [ -f $relayConfigPath ] && [ -f /usr/bin/perl ]; then
		GATHERURL_CONFIG=$( /usr/bin/perl -ne 'if( m#^__Installer_Masthead_GatherURL\s+=\s+(http://\S+)# ) { print $1; }' $relayConfigPath)
	fi

	CLIENT_RESTART_NEEDED=0
	if [ $SKIP_CLIENT_RESTART == "noskip" ]; then
		if [ -f /usr/bin/perl ]; then
			GATHERURL_MASTHEAD=$( /usr/bin/perl -ne 'if( m#^X-Fixlet-Site-Gather-URL:\s+(http://\S+)# ) { print $1; }' $BESClientActionMastheadPath )
				if [ "x$GATHERURL_MASTHEAD" != "x$GATHERURL_CONFIG" ]; then
					cat $relayConfigPath.default > $relayConfigPath
					setup_configfile $BESClientActionMastheadPath $relayConfigPath $GATHERURL_MASTHEAD

					CLIENT_RESTART_NEEDED=1
				fi
		else
			CLIENT_RESTART_NEEDED=1
		fi
	fi

	stackSizeHardLimitKB=$(ulimit -Hs)
	if [ "$stackSizeHardLimitKB" != "unlimited" ] && [ $stackSizeHardLimitKB -lt 10240 ]; then
		echo "Stack size hard limit ( ulimit -Hs ) too low = $stackSizeHardLimitKB."
		return 1
	fi

	stackSizeSoftLimitKB=$(ulimit -Ss)
	if [ "$stackSizeSoftLimitKB" = "unlimited" ] || [ $stackSizeSoftLimitKB -lt 10240 ]; then
		ulimit -Ss 10240
	fi

	/opt/BESRelay/bin/BESRelay 2> /dev/null
	ret=$?

	if [ $CLIENT_RESTART_NEEDED -eq 1 ]; then
		/bin/systemctl restart besclient >& /dev/null 
	fi

	return $ret
}

start_skipclientrestart() {
	echo SKIP_CLIENT_RESTART=skip > /etc/opt/BESClient/besrelay.env
	/bin/systemctl start besrelay >& /dev/null 
}

error() {
	echo The argument "$1" is not supported. Usage: besrelay.sh start_skipclientrestart
	return 1
}

case "$1" in
	start)
		# The start argument can be only used within the systemd unit file
		if [ $PPID -eq 1 ]; then
			start
		else 
			error "$1"
		fi
		;;
	start_skipclientrestart)
		start_skipclientrestart
		;;
	*)
		error "$1"
esac

exit $?
